@@ -11,7 +11,6 @@ use crate::runner::types::{Language, StatusResponse};
 
 #[derive(Debug, Clone)]
 pub struct Python {
-
     /// Example: python, python3, pypy2 or pypy3
     pub program: &'static str,
 
@@ -24,7 +23,7 @@ pub struct Python {
     /// Example ONLINE_JUDGE=1, etc
     #[allow(unused)]
     variables: Vec<&'static str>,
-    
+
     stdin: Option<PathBuf>,
 
     stdout: Option<PathBuf>,
@@ -33,10 +32,15 @@ pub struct Python {
 }
 
 impl Python {
-    pub fn new(program: &'static str, file_name: PathBuf, flags: Vec<&'static str>,
-        variables: Vec<&'static str>, stdin: Option<PathBuf>, stdout: Option<PathBuf>,
-        stderr: Option<PathBuf>) -> Python {
-        
+    pub fn new(
+        program: &'static str,
+        file_name: PathBuf,
+        flags: Vec<&'static str>,
+        variables: Vec<&'static str>,
+        stdin: Option<PathBuf>,
+        stdout: Option<PathBuf>,
+        stderr: Option<PathBuf>,
+    ) -> Python {
         Python {
             program: program,
             file_name: file_name,
@@ -44,27 +48,27 @@ impl Python {
             variables: variables,
             stdin: stdin,
             stdout: stdout,
-            stderr: stderr
+            stderr: stderr,
         }
     }
 }
 
 impl Language for Python {
-
     fn build(&self) -> bool {
         // no need to build
         true
     }
 
-    fn execute(&self, timeout: u32) -> StatusResponse {
+    fn execute(&self, timeout: u32, testcase: u32) -> StatusResponse {
         // Example: python3 main.py
         let commands = vec![self.program, self.file_name.to_str().unwrap()];
         execute_program(
             timeout,
+            testcase,
             commands,
             self.stdin.clone(),
             self.stdout.clone(),
-            self.stderr.clone()
+            self.stderr.clone(),
         )
     }
 
@@ -77,13 +81,16 @@ pub mod default {
     use std::path::PathBuf;
 
     use super::Python;
-    
-    pub fn python3_default(root: &str, file_name: &str,
-            input_file: &str, output_file: &str,
-            error_file: &str) -> Python {
-    
+
+    pub fn python3_default(
+        root: &str,
+        file_name: &str,
+        input_file: &str,
+        output_file: &str,
+        error_file: &str,
+    ) -> Python {
         let stdin = PathBuf::from(format!("{}/{}", root, input_file));
-        let stdout =  PathBuf::from(format!("{}/{}", root, output_file));
+        let stdout = PathBuf::from(format!("{}/{}", root, output_file));
         let stderr = PathBuf::from(format!("{}/{}", root, error_file));
 
         Python::new(
@@ -93,14 +100,12 @@ pub mod default {
             vec!["ONLINE_JUDGE=1"],
             Some(stdin),
             Some(stdout),
-            Some(stderr)
+            Some(stderr),
         )
     }
 
-    pub fn python3_set_output(root: &str, file_name: &str,
-            output_file: &str) -> Python {
-
-        let stdout =  PathBuf::from(format!("{}/{}", root, output_file));
+    pub fn python3_set_output(root: &str, file_name: &str, output_file: &str) -> Python {
+        let stdout = PathBuf::from(format!("{}/{}", root, output_file));
 
         Python::new(
             "python3",
@@ -109,7 +114,7 @@ pub mod default {
             vec!["ONLINE_JUDGE=1"],
             None,
             Some(stdout),
-            None
+            None,
         )
     }
-}
\ No newline at end of file
+}
